operatorauth

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package operatorauth authenticates operator identities independently of broker clients.

Index

Constants

This section is empty.

Variables

var (
	ErrMissing = errors.New("operator authentication required")
	ErrInvalid = errors.New("invalid operator credentials")
)

Functions

This section is empty.

Types

type Authenticator

type Authenticator struct {
	// contains filtered or unexported fields
}

Authenticator resolves dedicated operator credentials to stable identities.

func New

func New(secrets map[string]string, options Options) (*Authenticator, error)

New validates operator credentials and rejects reuse of any client secret.

func (*Authenticator) AuthenticateRequest

func (a *Authenticator) AuthenticateRequest(request *http.Request) (string, error)

AuthenticateRequest authenticates Bearer or Basic operator credentials.

type Options

type Options struct {
	MinSecretBytes int
	ClientSecrets  map[string]string
}

Options configures operator-secret authentication.

Jump to