operatorv1wire

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package operatorv1wire maps Operator V1 domain values to generated wire values.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func UseLimitFromWire

func UseLimitFromWire(limit nullable.Nullable[int]) usebudget.Limit

UseLimitFromWire converts a required nullable wire use limit to the domain.

func UseLimitToWire

func UseLimitToWire(limit usebudget.Limit) nullable.Nullable[int]

UseLimitToWire converts a required domain use limit to its nullable wire form.

Types

This section is empty.

Jump to