Documentation
¶
Overview ¶
Package brokerkit contains shared primitives for broker-style access-control services.
Index ¶
Constants ¶
const ModulePath = "github.com/osolmaz/brokerkit"
ModulePath is the canonical Go module path for brokerkit.
Variables ¶
This section is empty.
Functions ¶
func CanonicalModulePath ¶
func CanonicalModulePath() string
CanonicalModulePath returns the canonical Go module path for brokerkit.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package approval provides shared approval-channel decision handling.
|
Package approval provides shared approval-channel decision handling. |
|
Package audit writes secret-safe structured broker audit events.
|
Package audit writes secret-safe structured broker audit events. |
|
Package auth authenticates named broker clients from shared secrets.
|
Package auth authenticates named broker clients from shared secrets. |
|
Package clientconfig writes per-client broker environment files.
|
Package clientconfig writes per-client broker environment files. |
|
cmd
|
|
|
brokerkit-coverage
command
|
|
|
brokerkit-release
command
|
|
|
Package conformance provides reusable black-box broker contract tests.
|
Package conformance provides reusable black-box broker contract tests. |
|
Package controlplane assembles Brokerkit's shared broker control plane.
|
Package controlplane assembles Brokerkit's shared broker control plane. |
|
Package doctor provides secret-safe local broker isolation checks.
|
Package doctor provides secret-safe local broker isolation checks. |
|
Package envfile reads the strict environment files generated for broker services.
|
Package envfile reads the strict environment files generated for broker services. |
|
Package gitx contains provider-neutral Git smart-HTTP helpers.
|
Package gitx contains provider-neutral Git smart-HTTP helpers. |
|
Package grants stores short-lived broker approval grants.
|
Package grants stores short-lived broker approval grants. |
|
Package httpx contains small HTTP safety helpers for broker proxies.
|
Package httpx contains small HTTP safety helpers for broker proxies. |
|
Package installer contains the canonical broker-family binary installer.
|
Package installer contains the canonical broker-family binary installer. |
|
internal
|
|
|
copyx
Package copyx contains small internal copy helpers.
|
Package copyx contains small internal copy helpers. |
|
secretset
Package secretset validates and matches named shared-secret identities.
|
Package secretset validates and matches named shared-secret identities. |
|
validatex
Package validatex contains small validation helpers shared inside brokerkit.
|
Package validatex contains small validation helpers shared inside brokerkit. |
|
Package notify defines broker approval notification interfaces.
|
Package notify defines broker approval notification interfaces. |
|
telegram
Package telegram implements a reusable Telegram approval notifier.
|
Package telegram implements a reusable Telegram approval notifier. |
|
Package operatorapi exposes the Brokerkit operator inbox over protected HTTP.
|
Package operatorapi exposes the Brokerkit operator inbox over protected HTTP. |
|
Package operatorauth authenticates operator identities independently of broker clients.
|
Package operatorauth authenticates operator identities independently of broker clients. |
|
Package operatorclient is a small Go client for the Brokerkit operator API.
|
Package operatorclient is a small Go client for the Brokerkit operator API. |
|
Package operatorfake provides a real in-process operator API for consumer tests.
|
Package operatorfake provides a real in-process operator API for consumer tests. |
|
Package operatorinbox projects durable grants into bounded, operator-safe records.
|
Package operatorinbox projects durable grants into bounded, operator-safe records. |
|
Package policy evaluates broker authorization rules.
|
Package policy evaluates broker authorization rules. |
|
Package secretfile reads and renders deterministic named-secret files.
|
Package secretfile reads and renders deterministic named-secret files. |
|
Package service renders provider-neutral broker service definitions.
|
Package service renders provider-neutral broker service definitions. |
|
Package setup provides reusable broker setup command primitives.
|
Package setup provides reusable broker setup command primitives. |
|
Package store provides small durable local storage helpers.
|
Package store provides small durable local storage helpers. |
|
tooling
|
|
|
coverage
Package coverage runs a consistent Go coverage gate for broker repositories.
|
Package coverage runs a consistent Go coverage gate for broker repositories. |
|
release
Package release builds reproducible broker release archives.
|
Package release builds reproducible broker release archives. |
Click to show internal directories.
Click to hide internal directories.