Documentation
¶
Overview ¶
Package operatorauth authenticates operator identities independently of broker clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrMissing = errors.New("operator authentication required") ErrInvalid = errors.New("invalid operator credentials") )
Functions ¶
This section is empty.
Types ¶
type Authenticator ¶
type Authenticator struct {
// contains filtered or unexported fields
}
Authenticator resolves dedicated operator credentials to stable identities.
func New ¶
func New(secrets map[string]string, options Options) (*Authenticator, error)
New validates operator credentials and rejects reuse of any client secret.
func (*Authenticator) AuthenticateRequest ¶
func (a *Authenticator) AuthenticateRequest(request *http.Request) (string, error)
AuthenticateRequest authenticates Bearer or Basic operator credentials.
Click to show internal directories.
Click to hide internal directories.